@@ -40,6 +40,15 @@ enum byteState {
 int byteGet(FILE *fd) {
 	int byte;
 	enum byteState state;
+	/* No real reason to do this, but it makes the compiler happy. If this next line is not
+	   here the compiler generates this warning below:
+
+	   byte.c:76:16: warning: ‘byte’ may be used uninitialized in this function [-Wuninitialized]
+
+	   So let's initialize byte anyway.
+	*/
+	byte=0;
+
 	for(state=byteStateNibbleFirst;state!=byteStateComplete;) {
 		static int character;
 		switch(state) {
