@@ -209,6 +209,10 @@ void *listLast(list_t *list) {
 void *listSearch(list_t *list,int (*compare)(void *,void *),void *needle) {
 	void *data;
 	int found;
+	/* At first we of course didn't find anything and especially when
+	   we do not receive a list we make sure we did not found anything
+	   as of yet. */
+	found=0;
 	/* Does any element exist in the list? */
 	if((data=listFirst(list))!=NULL) {
 		do {
