@@ -23,9 +23,11 @@
 #define min(x,y) ((x)<(y)?(x):(y))
 
 typedef char bool_t;
-#define boolSet(x) (x)=1
-#define boolReset(x) (x)=0
-#define boolIsSet(x) ((x)==1)
-#define boolIsNotSet(x) ((x)==0)
+#define boolTrue 1
+#define boolFalse 0
+#define boolSet(x) ((x)=boolTrue)
+#define boolReset(x) ((x)=boolFalse)
+#define boolIsSet(x) ((x)==boolTrue)
+#define boolIsNotSet(x) ((x)==boolFalse)
 
 #endif
