@@ -27,16 +27,19 @@
 #include "crc16.h"
 #include "crc8.h"
 #include "list.h"
+#include "interface.h"
 #include "tty.h"
+#include "pty.h"
 
 static void usage(void) {
 	printf(
-		"Usage: %s [--version] [--help] [--checksum] [--crc16 poly] [--crc8 poly]\n"
-		"         [--fuck-up] [--file file] [--no-send]\n"
-		"         [--delay-line microseconds] [--delay-byte microseconds]\n"
-		"         [--print] [--size size] [--tty tty] [--width] [--pass] [--read]\n"
-		"         [--write] [--timing-print] [--timing-delta microseconds]\n"
-		"         [--ascii] [--alias-separator separator] [--byte-count] <file>\n",
+		"Usage: %s [--version] [--help] [--checksum] [--crc16=poly]\n"
+		"         [--crc8=poly] [--fuck-up] [--file=file] [--no-send]\n"
+		"         [--delay-line=microseconds] [--delay-byte=microseconds]\n"
+		"         [--print] [--size=size] [--tty=tty] [--pty [=alias]] [--width] [--pass]\n"
+		"         [--read] [--write] [--timing-print] [--timing-delta=microseconds]\n"
+		"         [--ascii] [--alias-separator=separator] [--byte-count]\n"
+		"         [--control] [--control-poll=microseconds] [--count=bytes] <file>\n",
 		PROGRAM_NAME
 	);
 }
@@ -60,10 +63,10 @@ static void optionsDefault(void) {
 	 * multiple I/O sources. Which we of course neglect anyway. */
 	sprintf(_jpnevulatorOptions.io,"%.*s",(int)sizeof(_jpnevulatorOptions.io)-1,ioMAGIC);
 
-	/* Initialize our list where we store our tty devices. We do not yet add the
-	 * default /dev/ttyS0 device. We postpone that up untill we know for sure the
-	 * user did not gave us a tty device. */
-	ttyInitialize();
+	/* Initialize the list where we store our interfaces. We do not yet add
+	 * the default interface. We postpone that up untill we know for sure the user
+	 * did not gave us any interface. */
+	interfaceInitialize();
 
 	/* By default we expect to send/receive Cham2 messages. */
 	_jpnevulatorOptions.size=22;
@@ -101,8 +104,17 @@ static void optionsDefault(void) {
 	/* Do not show the byte count by default. */
 	boolReset(_jpnevulatorOptions.byteCountDisplay);
 
-	/* Do not pass bytes between tty's by default. */
+	/* Do not pass bytes between interfaces by default. */
 	boolReset(_jpnevulatorOptions.pass);
+
+	/* Do not poll modem control bits by default. */
+	boolReset(_jpnevulatorOptions.control);
+
+	/* Poll every milisecond by default (should suffice for 9600bps). */
+	_jpnevulatorOptions.controlPoll=1000UL;
+
+	/* By default we read/write endlessly up untill the end of time. */
+	_jpnevulatorOptions.count=-1;
 }
 
 static void optionsIOWrite(char *file) {
@@ -122,6 +134,8 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 			{"ascii",no_argument,NULL,'a'},
 			{"byte-count",no_argument,NULL,'b'},
 			{"checksum",no_argument,NULL,'c'},
+			{"control",no_argument,NULL,'C'},
+			{"control-poll",required_argument,NULL,'D'},
 			{"delay-line",required_argument,NULL,'d'},
 			{"timing-delta",required_argument,NULL,'e'},
 			{"file",required_argument,NULL,'f'},
@@ -132,8 +146,10 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 			{"delay-byte",required_argument,NULL,'k'},
 			{"alias-separator",required_argument,NULL,'l'},
 			{"no-send",no_argument,NULL,'n'},
+			{"count",required_argument,NULL,'o'},
 			{"pass",no_argument,NULL,'P'},
 			{"print",no_argument,NULL,'p'},
+			{"pty",optional_argument,NULL,'q'},
 			{"read",no_argument,NULL,'r'},
 			{"size",required_argument,NULL,'s'},
 			{"tty",required_argument,NULL,'t'},
@@ -143,7 +159,7 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 			{"crc8",optional_argument,NULL,'z'},
 			{NULL,no_argument,NULL,0}
 		};
-		option=getopt_long(argc,argv,"acd:e:f:ghi:jl:npPrs:t:vwy:z:",long_options,&option_index);
+		option=getopt_long(argc,argv,"abcCd:D:e:f:ghi:jk:l:no:pPq:rs:t:vwy:z:",long_options,&option_index);
 		switch(option) {
 			case -1: {
 				finished=!finished;
@@ -161,6 +177,10 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 				_jpnevulatorOptions.checksum=checksumTypeChecksum;
 				break;
 			}
+			case 'C': {
+				boolSet(_jpnevulatorOptions.control);
+				break;
+			}
 			case 'd': {
 				unsigned long delay;
 				delay=atol(optarg);
@@ -171,6 +191,16 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 				}
 				break;
 			}
+			case 'D': {
+				unsigned long poll;
+				poll=atol(optarg);
+				if(poll>0) {
+					_jpnevulatorOptions.controlPoll=poll;
+				} else {
+					fprintf(stderr,"%s: Discarding control poll. It should be bigger than zero.\n",PROGRAM_NAME);
+				}
+				break;
+			}
 			case 'e': {
 				_jpnevulatorOptions.timingDelta=atol(optarg);
 				break;
@@ -219,6 +249,16 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 				boolReset(_jpnevulatorOptions.send);
 				break;
 			}
+			case 'o': {
+				int count;
+				count=atoi(optarg);
+				if(optarg>0) {
+					_jpnevulatorOptions.count=count;
+				} else {
+					fprintf(stderr,"%s: Discarding count. It should be bigger than zero.\n",PROGRAM_NAME);
+				}
+				break;
+			}
 			case 'p': {
 				boolSet(_jpnevulatorOptions.print);
 				break;
@@ -227,6 +267,10 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 				boolSet(_jpnevulatorOptions.pass);
 				break;
 			}
+			case 'q': {
+				ptyAdd(optarg);
+				break;
+			}
 			case 'r': {
 				if(_jpnevulatorOptions.action!=actionTypeNone) {
 					fprintf(stderr,"%s: Use --read or --write, but not both. Performing a read this time.\n",PROGRAM_NAME);
@@ -304,9 +348,9 @@ enum optionsRtrn optionsParse(int argc,char **argv) {
 		_jpnevulatorOptions.action=actionTypeWrite;
 	}
 
-	/* If the user did not mentioned any tty devices we will by default
+	/* If the user did not mentioned any interface we will by default
 	 * open the /dev/ttyS0 device. */
-	if(listElements(&_jpnevulatorOptions.tty)==0) {
+	if(listElements(&_jpnevulatorOptions.interface)==0) {
 		ttyAdd("/dev/ttyS0");
 	}
 
