@@ -19,24 +19,6 @@
 #ifndef __TTY_H
 #define __TTY_H
 
-struct tty {
-	char name[32];
-	char alias[32];
-	int fd;
-	unsigned long byteCount;
-};
-
-enum ttyRtrn {
-	ttyRtrnOk=0,
-	ttyRtrnDouble,
-	ttyRtrnMemory,
-	ttyRtrnOpen,
-	ttyRtrnList
-};
-
-#define ttyPrint(x) (strlen((x)->alias)>0?(x)->alias:(x)->name)
-extern void ttyInitialize(void);
-extern enum ttyRtrn ttyAdd(char *);
-extern void ttyDestroy(void);
+extern enum interfaceRtrn ttyAdd(char *);
 
 #endif
